@@ -1,5 +1,5 @@
 import os
-from typing import Any, Dict, List
+from typing import Any
 
 
 def expand_path(path: str) -> str:
@@ -13,20 +13,19 @@ def expand_paths(*paths):
 
 
 def build_base_options(
-    include_publisher_list: List[str],
-    include_abbr_list: List[str],
-    exclude_publisher_list: List[str],
-    exclude_abbr_list: List[str],
+    include_publisher_list: list[str],
+    include_abbr_list: list[str],
+    exclude_publisher_list: list[str],
+    exclude_abbr_list: list[str],
     path_conf_j_jsons: str,
-) -> Dict[str, Any]:
-    """
-    Build options dictionary with common configuration.
+) -> dict[str, Any]:
+    """Build options dictionary with common configuration.
 
     Args:
-        include_publisher_list: List of publishers to include
-        include_abbr_list: List of conference/journal abbreviations to include
-        exclude_publisher_list: List of publishers to exclude
-        exclude_abbr_list: List of conference/journal abbreviations to exclude
+        include_publisher_list: list of publishers to include
+        include_abbr_list: list of conference/journal abbreviations to include
+        exclude_publisher_list: list of publishers to exclude
+        exclude_abbr_list: list of conference/journal abbreviations to exclude
         path_conf_j_jsons: Base path for conferences/journals JSON files
 
     Returns:
@@ -45,14 +44,13 @@ def build_base_options(
 
 
 def build_search_options(
-    print_on_screen: bool, search_year_list: List[str], keywords_type: str, keywords_list_list: List[List[str]]
-) -> Dict[str, Any]:
-    """
-    Build search options dictionary with common configuration.
+    print_on_screen: bool, search_year_list: list[str], keywords_type: str, keywords_list_list: list[list[str]]
+) -> dict[str, Any]:
+    """Build search options dictionary with common configuration.
 
     Args:
         print_on_screen: Whether to display results on screen
-        search_year_list: List of years to filter search results
+        search_year_list: list of years to filter search results
         keywords_type: Category name for search keywords
         keywords_list_list: Nested list of search keywords
 
