@@ -2,6 +2,8 @@ import os
 
 from pyeasyphd.tools import PyRunBibMdTex
 
+from ._base import expand_path
+
 
 def run_article_md_daily_notes(
     path_input_file: str,
@@ -11,12 +13,11 @@ def run_article_md_daily_notes(
     path_conf_j_jsons: str,
     options: dict,
 ) -> None:
-    """
-    Run article markdown daily notes processing pipeline.
+    """Run article markdown daily notes processing pipeline.
 
     Args:
         path_input_file (str): Path to input files directory
-        input_file_names (list[str]): List of input file names
+        input_file_names (list[str]): list of input file names
         path_output_file (str): Path to output directory
         bib_path_or_file (str): Path to bibliography file or directory
         path_conf_j_jsons (str): Path to conferences and journals JSON files directory
@@ -25,30 +26,32 @@ def run_article_md_daily_notes(
     Returns:
         None
     """
-    path_input_file = os.path.expandvars(os.path.expanduser(path_input_file))
-    path_output_file = os.path.expandvars(os.path.expanduser(path_output_file))
+    path_input_file = expand_path(path_input_file)
+    path_output_file = expand_path(path_output_file)
 
     # Initialize default options with detailed descriptions
     _options = {
-        "full_json_c": os.path.expanduser(os.path.join(path_conf_j_jsons, "conferences.json")),
-        "full_json_j": os.path.expanduser(os.path.join(path_conf_j_jsons, "journals.json")),
+        "full_json_c": expand_path(os.path.join(path_conf_j_jsons, "conferences.json")),
+        "full_json_j": expand_path(os.path.join(path_conf_j_jsons, "journals.json")),
         # figure options
         "includegraphics_figs_directory": "",
         "shutil_includegraphics_figs": False,
         "includegraphics_figs_in_relative_path": True,
         "figure_folder_name": "figs",  # "" or "figs" or "main"
         # bib options
+        "is_standardize_bib": False,  # default is True
+        "function_common_again": False,  # default is True
         "abbr_index_article_for_abbr": 1,  # 0, 1, 2
         "abbr_index_inproceedings_for_abbr": 2,  # 0, 1, 2
         "add_link_to_fields_for_abbr": ["title"],  # None, or ["title", "journal", "booktitle"]
         "maximum_authors_for_abbr": 0,  # 0, 1, 2, ...
         "add_index_to_entries": False,
-        "bib_for_abbr_name": "abbr.bib",
-        "bib_for_zotero_name": "zotero.bib",
-        "bib_for_save_name": "save.bib",
+        "bib_name_for_abbr": "abbr.bib",
+        "bib_name_for_zotero": "zotero.bib",
+        "bib_name_for_save": "save.bib",
         "bib_folder_name": "bibs",  # "" or "bib" or "bibs" or "main"
         "delete_original_bib_in_output_folder": True,  # default is False
-        "bib_path_or_file": os.path.expanduser(bib_path_or_file),
+        "bib_path_or_file": expand_path(bib_path_or_file),
         # tex options
         "handly_preamble": False,
         "final_output_main_tex_name": "main.tex",
