@@ -1,21 +1,18 @@
-from typing import Optional
-
 from pybibtexer.tools import replace_to_standard_cite_keys
 
 from ._base import build_base_options, expand_paths
 
 
 def run_replace_to_standard_cite_keys(
-    full_tex_md: str, full_bib: str, path_output: str, path_conf_j_jsons: str, options: Optional[dict] = None
+    full_tex_md: str, full_bib: str, path_output: str, path_conf_j_jsons: str, options: dict | None = None
 ) -> None:
-    """
-    Replace citation keys in LaTeX documents with standardized versions.
+    """Replace citation keys in LaTeX documents with standardized versions.
 
     Processes LaTeX and BibTeX files to normalize citation keys according to
     configuration standards, then outputs the results to the specified location.
 
     Args:
-        options: Dictionary of configuration options for citation processing
+        options: dictionary of configuration options for citation processing
         full_tex_md: Path to TeX or Markdown file containing citations
         full_bib: Path to the BibTeX bibliography file
         path_output: Output directory path for processed files
